/*
 * Vifir - An electronic flight bag wannabe utility for aircraft pilots
 * Copyright (C) 2009 David Ludlow
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * dave@adsllc.com, PO Box 13070, Toledo, OH 43623
 */

#ifndef CHARTCHOOSERDIALOG_H_
#define CHARTCHOOSERDIALOG_H_

#include <string>
#include <gtkmm/dialog.h>
#include <gtkmm/drawingarea.h>
#include <gtkmm/radiobutton.h>
#include <gtkmm/combobox.h>
#include <gtkmm/liststore.h>
#include <gtkmm/label.h>
#include <libglademm.h>
#include "Config.h"
#include "DataStore.h"
#include "ChartChooserDrawingArea.h"
#include "Route.h"

class ChartChooserDialog
{
public:
	ChartChooserDialog(std::string *GladeFilename, Config *Cfg, DataStore *Data, Route *RouteData);
	virtual ~ChartChooserDialog();

	int Run();
	std::vector<GeoChart*>::iterator GetSelectedChart();

private:

	class FlywayComboModelColumns : public Gtk::TreeModel::ColumnRecord {
	public:

		FlywayComboModelColumns() { add(Name); add(Charti); }

		Gtk::TreeModelColumn<std::string> Name;
		Gtk::TreeModelColumn<std::vector<GeoChart*>::iterator> Charti;
	};

	void on_Sectionals_clicked();
	void on_TACs_clicked();
	void on_Flyways_clicked();
	bool on_button_release_event(GdkEventButton * event);
	void on_FlywayComboBox_changed();
	void SetSelectedLabel();

	Glib::RefPtr<Gnome::Glade::Xml> refXml;
	Gtk::Dialog *GtkDialog;
	ChartChooserDrawingArea *HawaiiDrawingArea;
	ChartChooserDrawingArea *AlaskaDrawingArea;
	ChartChooserDrawingArea *ContiguousDrawingArea;
	Gtk::RadioButton *SectionalsRadioButton;
	Gtk::RadioButton *TACsRadioButton;
	Gtk::RadioButton *FlywaysRadioButton;
	Gtk::ComboBox *FlywayComboBox;
	Gtk::Label *SelectedLabel;

	FlywayComboModelColumns FlywayComboColumns;
	Glib::RefPtr<Gtk::ListStore> FlywayComborefTreeModel;

	std::vector<GeoChart*>::iterator SelectedCharti; 
	Config *Cfg;
	DataStore *Data;
};

#endif /*CHARTCHOOSERDIALOG_H_*/
