/*
 * Vifir - An electronic flight bag wannabe utility for aircraft pilots
 * Copyright (C) 2009 David Ludlow
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * dave@adsllc.com, PO Box 13070, Toledo, OH 43623
 */

#ifdef HAVE_CONFIG_H
 #include "../config.h"
#endif

#ifndef GPS_H_
#define GPS_H_

#include <time.h>

#ifdef HAVE_LIBGPS
#include <gps.h>
#endif

#include "Config.h"

class GPS
{
public:
	GPS(Config *Cfg);
	virtual ~GPS();

	bool Activate();
	void Deactivate();
	bool GetActive();
	bool GetFix(double *Lon=NULL, double *Lat=NULL, double *Alt=NULL, double *Trk=NULL, double *Spd=NULL);

private:
#ifdef HAVE_LIBGPS
	gps_data_t *gpsddata;
	pthread_t handler;
#endif
	bool ActiveFlag;
	bool gpsdActiveFlag;

	Config *Cfg;

private:
	/* Store this data for use by the simulation code */
	double Lon,Lat,Alt,Trk,Spd;
	time_t LonLatTime;		/* Time Lon & Lat were received */
	time_t AltTime;		/* Time altitude was received */
	time_t VelTime;		/* Time velocity (Trk/Spd) was received */

};

#endif /*GPS_H_*/
