/*
 * Vifir - An electronic flight bag wannabe utility for aircraft pilots
 * Copyright (C) 2009 David Ludlow
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * dave@adsllc.com, PO Box 13070, Toledo, OH 43623
 */

#include <glibmm/i18n.h>
#include <gtkmm/messagedialog.h>
#include <gtkmm/main.h>
#ifdef HAVE_CONFIG_H
 #include "../config.h"
#endif

#include "ImportDialog.h"
#include "Exception.h"
#include "ImportdTPPDVD.h"
#include "ImportSectionalsDVD.h"
#include "ImportDigitalAeroInformation.h"
#include "ImportNationalFlightDatabase.h"
#include "ImportShapefile.h"
#include "ImportXPlane900Data.h"

ImportDialog::ImportDialog(Config *Cfg, std::string *GladeFilename, DataStore *Data, Shapefile *ShapefileData)
{
	try
	{
		refXml = Gnome::Glade::Xml::create(*GladeFilename, "ImportDialog");
	}
	catch (const Gnome::Glade::XmlError& ex)
	{
		Gtk::MessageDialog *message = new Gtk::MessageDialog(_("Error reading data file: ")+*GladeFilename+"\n"+_("Program cannot continue."),
			false,Gtk::MESSAGE_ERROR,Gtk::BUTTONS_CANCEL,true);
		message->run();
		Gtk::Main::quit();
	}

	refXml->get_widget("ImportDialog",GtkDialog);
	refXml->get_widget("FlightDBCDButton",FlightDBCDButton);
	refXml->get_widget("XPlane900DataButton",XPlane900DataButton);
	refXml->get_widget("SectionalsDVDButton",SectionalsDVDButton);
	refXml->get_widget("ApproachesDVDButton",ApproachesDVDButton);
	refXml->get_widget("ShapefileButton",ShapefileButton);

	FlightDBCDButton->signal_clicked().connect(sigc::mem_fun(this,&ImportDialog::on_FlightDBCDButton_clicked));
	XPlane900DataButton->signal_clicked().connect(sigc::mem_fun(this,&ImportDialog::on_XPlane900DataButton_clicked));
	SectionalsDVDButton->signal_clicked().connect(sigc::mem_fun(this,&ImportDialog::on_SectionalsDVDButton_clicked));
	ApproachesDVDButton->signal_clicked().connect(sigc::mem_fun(this,&ImportDialog::on_ApproachesDVDButton_clicked));
	ShapefileButton->signal_clicked().connect(sigc::mem_fun(this,&ImportDialog::on_ShapefileButton_clicked));

	this->Cfg=Cfg;
	this->GladeFilename=GladeFilename;
	this->Data=Data;
	this->ShapefileData=ShapefileData;

#ifndef HAVE_LIBZIP
	/* libzip support is needed to process the X-Plane 9.00 data */
	XPlane900DataButton->set_sensitive(false);
#endif
}

ImportDialog::~ImportDialog()
{
	delete GtkDialog;
}

void ImportDialog::Run() {
	GtkDialog->run();
}

void ImportDialog::on_FlightDBCDButton_clicked() {
	try {
		ImportNationalFlightDatabase Import(Cfg,GladeFilename,Data);
		Import.Run();
	}
	catch (Exception Ex) {
		Ex.Show();
	}
}

void ImportDialog::on_XPlane900DataButton_clicked() {
	try {
		ImportXPlane900Data Import(Cfg,GladeFilename,Data);
		Import.Run();
	}
	catch (Exception Ex) {
		Ex.Show();
	}
}

void ImportDialog::on_SectionalsDVDButton_clicked() {
	try {
		ImportSectionalsDVD Import(Cfg,GladeFilename,Data);
		Import.Run();
	}
	catch (Exception Ex) {
		Ex.Show();
	}
}

void ImportDialog::on_ApproachesDVDButton_clicked() {
	try {
		ImportdTPPDVD Import(Cfg,GladeFilename,Data);
		Import.Run();
	}
	catch (Exception Ex) {
		Ex.Show();
	}
}

void ImportDialog::on_ShapefileButton_clicked() {
	try {
		ImportShapefile Import(Cfg,GladeFilename,ShapefileData);
		Import.Run();
	}
	catch (Exception Ex) {
		Ex.Show();
	}
}
